@@ -11,7 +11,7 @@ fi;
 
 # -Dfile.encoding=UTF-8 ensure Unicode characters in model files are compatible cross-platform
 
-JVM_OPTS=(-XX:MaxRAMPercentage=50 -Dfile.encoding=UTF-8 -Dnetlogo.extensions.dir="${BASE_DIR}/extensions" -Dnetlogo.models.dir="${BASE_DIR}/models" --add-exports=java.base/java.lang=ALL-UNNAMED --add-exports=java.desktop/sun.awt=ALL-UNNAMED --add-exports=java.desktop/sun.java2d=ALL-UNNAMED  )
+JVM_OPTS=(-XX:MaxRAMPercentage=50 -Dfile.encoding=UTF-8 -Dnetlogo.extensions.dir="${BASE_DIR}/extensions" -Dnetlogo.models.dir="${BASE_DIR}/models" --add-exports=java.base/java.lang=ALL-UNNAMED --add-exports=java.desktop/sun.awt=ALL-UNNAMED --add-exports=java.desktop/sun.java2d=ALL-UNNAMED  [])
 ARGS=()
 
 for arg in "$@"; do
@@ -24,7 +24,7 @@ for arg in "$@"; do
   fi
 done
 
-ABSOLUTE_CLASSPATH="$BASE_DIR/lib/app/netlogo-7.0.0.jar"
+ABSOLUTE_CLASSPATH="$BASE_DIR/lib/app/netlogo-7.0.3.jar"
 
 # -classpath ....         specify jars
 # org.nlogo.headless.Main specify we want headless, not GUI
